@@ -18,24 +18,25 @@ LOCK_STATES = Bunch(
     failed="failed",
 )
 
-STATUS_CODES = {"SUCCESS": "000", "ERROR": "997"}
-AUTOLOCK_ENABLE = "FF"
+
 AUTOLOCK_DISABLE = "00"
+AUTOLOCK_ENABLE = "FF"
 
-CONFIG_VOLUME_IDX = "01"
-CONFIG_AUTOLOCK_IDX = "02"
-CONFIG_LANG_IDX = "05"
+CONFIG_IDX_AUTOLOCK = "02"
+CONFIG_IDX_LANG = "05"
+CONFIG_IDX_VOLUME = "01"
 
-LANG_EN = "01"
 LANG_DA = "04"
-LANG_NO = "05"
-LANG_SE = "06"
+LANG_EN = "01"
 LANG_FI = "07"
+LANG_NO = "05"
 LANG_RU = "08"
+LANG_SE = "06"
 LANG_TR = "10"
+STATUS_CODES = {"SUCCESS": "000", "ERROR": "997"}
 VOLUME_HIGH = "03"
 VOLUME_LOW = "02"
 VOLUME_OFF = "01"
+YALE_LOCK_STATE_DOOR_OPEN = "dooropen"
 YALE_LOCK_STATE_LOCKED = "device_status.lock"
 YALE_LOCK_STATE_UNLOCKED = "device_status.unlock"
-YALE_LOCK_STATE_DOOR_OPEN = "dooropen"
